@@ -1,5 +1,5 @@
 # --
-# Copyright (C) 2001-2018 OTRS AG, https://otrs.com/
+# Copyright (C) 2001-2019 OTRS AG, https://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -387,9 +387,12 @@ sub _ShowEdit {
 
         # Create use Proxy select.
         $Param{UseProxyStrg} = $LayoutObject->BuildSelection(
-            Data          => [ 'No', 'Yes' ],
+            Data => {
+                'No'  => Translatable('No'),
+                'Yes' => Translatable('Yes'),
+            },
             Name          => 'UseProxy',
-            SelectedValue => $Param{UseProxy} || 'No',
+            SelectedValue => $Param{UseProxy} || Translatable('No'),
             PossibleNone  => 0,
             Sort          => 'AlphanumericValue',
             Class         => 'Modernize',
@@ -397,9 +400,12 @@ sub _ShowEdit {
 
         # Create Proxy exclude select.
         $Param{ProxyExcludeStrg} = $LayoutObject->BuildSelection(
-            Data          => [ 'No', 'Yes' ],
+            Data => {
+                'No'  => Translatable('No'),
+                'Yes' => Translatable('Yes'),
+            },
             Name          => 'ProxyExclude',
-            SelectedValue => $Param{ProxyExclude} || 'No',
+            SelectedValue => $Param{ProxyExclude} || Translatable('No'),
             PossibleNone  => 0,
             Sort          => 'AlphanumericValue',
             Class         => 'Modernize',
@@ -414,9 +420,12 @@ sub _ShowEdit {
 
         # Create use SSL select.
         $Param{UseSSLStrg} = $LayoutObject->BuildSelection(
-            Data          => [ 'No', 'Yes' ],
+            Data => {
+                'No'  => Translatable('No'),
+                'Yes' => Translatable('Yes'),
+            },
             Name          => 'UseSSL',
-            SelectedValue => $Param{UseSSL} || 'No',
+            SelectedValue => $Param{UseSSL} || Translatable('No'),
             PossibleNone  => 0,
             Sort          => 'AlphanumericValue',
             Class         => 'Modernize',
@@ -502,8 +511,8 @@ sub _ShowEdit {
 
         $Param{KeepAliveStrg} = $LayoutObject->BuildSelection(
             Data => {
-                0 => 'No',
-                1 => 'Yes',
+                0 => Translatable('No'),
+                1 => Translatable('Yes'),
             },
             Name         => 'KeepAlive',
             SelectedID   => $Param{KeepAlive} || 0,
