@@ -166,7 +166,7 @@ sub Run {
     }
 
     # Notify if there are tickets which are not updated.
-    $Output .= $LayoutObject->NotifyNonUpdatedTickets();
+    $Output .= $LayoutObject->NotifyNonUpdatedTickets() // '';
 
     # get locked  viewable tickets...
     my $SortByS = $SortBy;
@@ -183,7 +183,7 @@ sub Run {
                 OwnerIDs   => [ $Self->{UserID} ],
                 OrderBy    => $OrderBy,
                 SortBy     => $SortByS,
-                UserID     => 1,
+                UserID     => $Self->{UserID},
                 Permission => 'ro',
             },
         },
@@ -199,7 +199,7 @@ sub Run {
                 TicketFlagUserID => $Self->{UserID},
                 OrderBy          => $OrderBy,
                 SortBy           => $SortByS,
-                UserID           => 1,
+                UserID           => $Self->{UserID},
                 Permission       => 'ro',
             },
         },
@@ -212,7 +212,7 @@ sub Run {
                 OwnerIDs   => [ $Self->{UserID} ],
                 OrderBy    => $OrderBy,
                 SortBy     => $SortByS,
-                UserID     => 1,
+                UserID     => $Self->{UserID},
                 Permission => 'ro',
             },
         },
@@ -226,7 +226,7 @@ sub Run {
                 OwnerIDs                      => [ $Self->{UserID} ],
                 OrderBy                       => $OrderBy,
                 SortBy                        => $SortByS,
-                UserID                        => 1,
+                UserID                        => $Self->{UserID},
                 Permission                    => 'ro',
             },
         },
