@@ -111,15 +111,50 @@ sub Run {
 
     my $UserObject = $Kernel::OM->Get('Kernel::System::CustomerUser');
 
-    # add filter for customer company if not disabled
+    my @CustomerIDs;
+
+    # Add filter for customer company if the company tickets are not disabled.
     if ( !$DisableCompanyTickets ) {
+        my %AccessibleCustomers = $Kernel::OM->Get('Kernel::System::CustomerGroup')->GroupContextCustomers(
+            CustomerUserID => $Self->{UserID},
+        );
+
+        # Show customer companies as additional filter selection.
+        if ( $Self->{Subaction} eq 'CompanyTickets' && scalar keys %AccessibleCustomers > 1 ) {
+
+            @CustomerIDs = $ParamObject->GetArray( Param => 'CustomerIDs' );
+
+            # Prevent array item duplication.
+            my %CustomerIDsHash = map { $_ => 1 } @CustomerIDs;
+            @CustomerIDs = sort keys %CustomerIDsHash;
+
+            $Param{CustomerIDStrg} = $LayoutObject->BuildSelection(
+                Data       => \%AccessibleCustomers,
+                Name       => 'CustomerIDs',
+                Multiple   => 1,
+                Size       => 1,
+                SelectedID => \@CustomerIDs,
+                Class      => 'Modernize',
+            );
+
+            # Remember the active customer ID filter.
+            $Param{CustomerIDs} = '';
+            for my $CustomerID (@CustomerIDs) {
+                $Param{CustomerIDs} .= ';CustomerIDs=' . $LayoutObject->LinkEncode($CustomerID);
+            }
+        }
+        else {
+
+            # Default behavior - use all available customer IDs.
+            @CustomerIDs = sort keys %AccessibleCustomers;
+        }
+
         $Filters{CompanyTickets} = {
             All => {
                 Name   => 'All',
                 Prio   => 1000,
                 Search => {
-                    CustomerIDRaw =>
-                        [ $UserObject->CustomerIDs( User => $Self->{UserLogin} ) ],
+                    CustomerIDRaw  => \@CustomerIDs,
                     OrderBy        => $OrderByCurrent,
                     SortBy         => $SortBy,
                     CustomerUserID => $Self->{UserID},
@@ -130,8 +165,7 @@ sub Run {
                 Name   => 'Open',
                 Prio   => 1100,
                 Search => {
-                    CustomerIDRaw =>
-                        [ $UserObject->CustomerIDs( User => $Self->{UserLogin} ) ],
+                    CustomerIDRaw  => \@CustomerIDs,
                     StateType      => 'Open',
                     OrderBy        => $OrderByCurrent,
                     SortBy         => $SortBy,
@@ -143,8 +177,7 @@ sub Run {
                 Name   => 'Closed',
                 Prio   => 1200,
                 Search => {
-                    CustomerIDRaw =>
-                        [ $UserObject->CustomerIDs( User => $Self->{UserLogin} ) ],
+                    CustomerIDRaw  => \@CustomerIDs,
                     StateType      => 'Closed',
                     OrderBy        => $OrderByCurrent,
                     SortBy         => $SortBy,
@@ -192,7 +225,7 @@ sub Run {
             %{ $Filters{ $Self->{Subaction} }->{$Filter}->{Search} },
             %SearchInArchive,
             Result => 'COUNT',
-        );
+        ) || 0;
 
         my $ClassA = '';
         if ( $Filter eq $FilterCurrent ) {
@@ -266,6 +299,14 @@ sub Run {
             . ';Filter=' . $LayoutObject->Ascii2Html( Text => $FilterCurrent )
             . ';Subaction=' . $LayoutObject->Ascii2Html( Text => $Self->{Subaction} )
             . ';';
+
+        # Add CustomerIDs parameter if needed.
+        if ( IsArrayRefWithData( \@CustomerIDs ) ) {
+            for my $CustomerID (@CustomerIDs) {
+                $Link .= "CustomerIDs=$CustomerID;";
+            }
+        }
+
         my %PageNav = $LayoutObject->PageNavBar(
             Limit     => 10000,
             StartHit  => $StartHit,
@@ -358,6 +399,7 @@ sub Run {
             $LayoutObject->Block(
                 Name => 'FilterHeader',
                 Data => {
+                    %Param,
                     %{ $NavBarFilter{$Key} },
                 },
             );
@@ -378,7 +420,10 @@ sub Run {
                 $LayoutObject->Block(
                     Name => 'FilterFooterItem',
                     Data => {
+                        %Param,
+                        %PageNav,
                         %{ $NavBarFilter{$Key} },
+
                     },
                 );
             }
@@ -576,47 +621,26 @@ sub Run {
 sub ShowTicketStatus {
     my ( $Self, %Param ) = @_;
 
-    my $LayoutObject = $Kernel::OM->Get('Kernel::Output::HTML::Layout');
-    my $TicketObject = $Kernel::OM->Get('Kernel::System::Ticket');
-    my $TicketID     = $Param{TicketID} || return;
+    my $LayoutObject               = $Kernel::OM->Get('Kernel::Output::HTML::Layout');
+    my $TicketObject               = $Kernel::OM->Get('Kernel::System::Ticket');
+    my $ArticleObject              = $Kernel::OM->Get('Kernel::System::Ticket::Article');
+    my $CommunicationChannelObject = $Kernel::OM->Get('Kernel::System::CommunicationChannel');
+    my $TicketID                   = $Param{TicketID} || return;
+
+    # Get last customer article.
+    my @ArticleList = $ArticleObject->ArticleList(
+        TicketID             => $Param{TicketID},
+        IsVisibleForCustomer => 1,
+        OnlyLast             => 1,
+    );
 
-    # contains last article (non-internal)
     my %Article;
-
-    # get whole article index
-    my @ArticleIDs = $TicketObject->ArticleIndex( TicketID => $Param{TicketID} );
-
-    # get article data
-    if (@ArticleIDs) {
-        my %LastNonInternalArticle;
-
-        ARTICLEID:
-        for my $ArticleID ( reverse @ArticleIDs ) {
-            my %CurrentArticle = $TicketObject->ArticleGet( ArticleID => $ArticleID );
-
-            # check for non-internal and non-chat article
-            next ARTICLEID if $CurrentArticle{ArticleType} =~ m{internal|chat}smx;
-
-            # check for customer article
-            if ( $CurrentArticle{SenderType} eq 'customer' ) {
-                %Article = %CurrentArticle;
-                last ARTICLEID;
-            }
-
-            # check for last non-internal article (sender type does not matter)
-            if ( !%LastNonInternalArticle ) {
-                %LastNonInternalArticle = %CurrentArticle;
-            }
-        }
-
-        if ( !%Article && %LastNonInternalArticle ) {
-            %Article = %LastNonInternalArticle;
-        }
-    }
-
-    my $NoArticle;
-    if ( !%Article ) {
-        $NoArticle = 1;
+    if ( $ArticleList[0] && IsHashRefWithData( $ArticleList[0] ) ) {
+        my $ArticleBackendObject = $ArticleObject->BackendForArticle( %{ $ArticleList[0] } );
+        %Article = $ArticleBackendObject->ArticleGet(
+            TicketID  => $Param{TicketID},
+            ArticleID => $ArticleList[0]->{ArticleID},
+        );
     }
 
     # get ticket info
@@ -632,15 +656,15 @@ sub ShowTicketStatus {
     # Check if the last customer subject or ticket title should be shown.
     # If ticket title should be shown, check if there are articles, because ticket title
     # could be related with a subject of an article which does not visible for customer (see bug#13614).
-    # If there is no subject, set to 'Untitled!'.
+    # If there is no subject, set to 'Untitled'.
     if ( $SmallViewColumnHeader eq 'LastCustomerSubject' ) {
         $Subject = $Article{Subject} || '';
     }
-    elsif ( $SmallViewColumnHeader eq 'TicketTitle' && !$NoArticle ) {
+    elsif ( $SmallViewColumnHeader eq 'TicketTitle' && $ArticleList[0] ) {
         $Subject = $Ticket{Title};
     }
     else {
-        $Subject = 'Untitled!';
+        $Subject = Translatable('Untitled!');
     }
 
     # Condense down the subject.
@@ -649,23 +673,17 @@ sub ShowTicketStatus {
         Subject      => $Subject,
     );
 
+    # Age design.
+    $Ticket{CustomerAge} = $LayoutObject->CustomerAge(
+        Age   => $Ticket{Age},
+        Space => ' '
+    ) || 0;
+
     # return ticket information if there is no article
-    if ($NoArticle) {
+    if ( !IsHashRefWithData( \%Article ) ) {
         $Article{State}        = $Ticket{State};
         $Article{TicketNumber} = $Ticket{TicketNumber};
-        $Article{CustomerAge}  = $LayoutObject->CustomerAge(
-            Age   => $Ticket{Age},
-            Space => ' '
-        ) || 0;
-        $Article{Body} = $LayoutObject->{LanguageObject}->Translate('This item has no articles yet.');
-    }
-
-    # otherwise return article information
-    else {
-        $Article{CustomerAge} = $LayoutObject->CustomerAge(
-            Age   => $Article{Age},
-            Space => ' '
-        ) || 0;
+        $Article{Body}         = $LayoutObject->{LanguageObject}->Translate('This item has no articles yet.');
     }
 
     # customer info (customer name)
@@ -814,6 +832,8 @@ sub ShowTicketStatus {
             );
         }
     }
+
+    return;
 }
 
 1;
