@@ -1,5 +1,5 @@
 # --
-# Copyright (C) 2001-2020 OTRS AG, https://otrs.com/
+# Copyright (C) 2001-2019 OTRS AG, https://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -8,30 +8,20 @@
 
 package Kernel::Output::HTML::ToolBar::TicketLocked;
 
+use parent 'Kernel::Output::HTML::Base';
+
 use strict;
 use warnings;
 
 use Kernel::Language qw(Translatable);
 
 our @ObjectDependencies = (
+    'Kernel::Config',
+    'Kernel::Output::HTML::Layout',
     'Kernel::System::Log',
     'Kernel::System::Ticket',
-    'Kernel::Output::HTML::Layout',
 );
 
-sub new {
-    my ( $Type, %Param ) = @_;
-
-    # allocate new hash for object
-    my $Self = {};
-    bless( $Self, $Type );
-
-    # get UserID param
-    $Self->{UserID} = $Param{UserID} || die "Got no UserID!";
-
-    return $Self;
-}
-
 sub Run {
     my ( $Self, %Param ) = @_;
 
@@ -46,6 +36,8 @@ sub Run {
         }
     }
 
+    return if !$Kernel::OM->Get('Kernel::Config')->Get('Frontend::Module')->{AgentTicketLockedView};
+
     # get ticket object
     my $TicketObject = $Kernel::OM->Get('Kernel::System::Ticket');
 
@@ -56,7 +48,7 @@ sub Run {
         OwnerIDs   => [ $Self->{UserID} ],
         UserID     => $Self->{UserID},
         Permission => 'ro',
-    );
+    ) || 0;
     my $CountNew = $TicketObject->TicketSearch(
         Result     => 'COUNT',
         Locks      => [ 'lock', 'tmp_lock' ],
@@ -67,7 +59,7 @@ sub Run {
         TicketFlagUserID => $Self->{UserID},
         UserID           => $Self->{UserID},
         Permission       => 'ro',
-    );
+    ) || 0;
     $CountNew = $Count - $CountNew;
     my $CountReached = $TicketObject->TicketSearch(
         Result                        => 'COUNT',
@@ -77,7 +69,7 @@ sub Run {
         OwnerIDs                      => [ $Self->{UserID} ],
         UserID                        => $Self->{UserID},
         Permission                    => 'ro',
-    );
+    ) || 0;
 
     my $Class        = $Param{Config}->{CssClass};
     my $ClassNew     = $Param{Config}->{CssClassNew};
