@@ -1,5 +1,5 @@
 # --
-# Copyright (C) 2001-2018 OTRS AG, https://otrs.com/
+# Copyright (C) 2001-2019 OTRS AG, https://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -11,22 +11,22 @@ package Kernel::System::Console::Command::Dev::Tools::TranslationsUpdate;
 use strict;
 use warnings;
 
-use base qw(Kernel::System::Console::BaseCommand);
+use parent qw(Kernel::System::Console::BaseCommand);
 
 use File::Basename;
 use File::Copy;
 use Lingua::Translit;
 use Pod::Strip;
-use Storable ();
 
 use Kernel::Language;
 
 our @ObjectDependencies = (
     'Kernel::Config',
+    'Kernel::System::DateTime',
     'Kernel::System::Encode',
     'Kernel::System::Main',
+    'Kernel::System::Storable',
     'Kernel::System::SysConfig',
-    'Kernel::System::Time',
 );
 
 sub Configure {
@@ -50,7 +50,7 @@ sub Configure {
     $Self->AddOption(
         Name => 'generate-po',
         Description =>
-            "Generate PO (translation content) files. This is only needed if a module is not yet available in transifex to force initial creation of the gettext files.",
+            "Generate PO (translation content) files. This is only needed if a module is not yet available in Transifex to force initial creation of the gettext files.",
         Required => 0,
         HasValue => 0,
     );
@@ -133,6 +133,9 @@ sub Run {
 
 my @OriginalTranslationStrings;
 
+# Remember which strings came from JavaScript
+my %UsedInJS;
+
 sub HandleLanguage {
     my ( $Self, %Param ) = @_;
 
@@ -171,7 +174,7 @@ sub HandleLanguage {
 
         # remove underscores and/or version numbers and following from module name
         # i.e. FAQ_2_0 or FAQ20
-        $Module =~ s{ [[(?:_|\-)0-9]+ .+ \z }{}xms;
+        $Module =~ s/((_|\-)?(\d+))+$//gix;
 
         # save module directory in target file
         $TargetFile = "$ModuleDirectory/Kernel/Language/${Language}_$Module.pm";
@@ -253,7 +256,7 @@ sub HandleLanguage {
                 $Word =~ s{\\"}{"}smxg;
                 $Word =~ s{\\'}{'}smxg;
 
-                if (!$UsedWords{$Word}++) {
+                if ( $Word && !$UsedWords{$Word}++ ) {
 
                     push @OriginalTranslationStrings, {
                         Location => "Template: $File",
@@ -266,6 +269,76 @@ sub HandleLanguage {
             }egx;
         }
 
+        # Add strings from .html.tmpl files (JavaScript templates).
+        my $JSTemplatesDirectory = $IsSubTranslation
+            ? "$ModuleDirectory/Kernel/Output/JavaScript/Templates/$DefaultTheme"
+            : "$Home/Kernel/Output/JavaScript/Templates/$DefaultTheme";
+
+        my @JSTemplateList;
+        if ( -d $JSTemplatesDirectory ) {
+            @JSTemplateList = $Kernel::OM->Get('Kernel::System::Main')->DirectoryRead(
+                Directory => $JSTemplatesDirectory,
+                Filter    => '*.html.tmpl',
+                Recursive => 1,
+            );
+        }
+
+        my $CustomJSTemplatesDir = "$ModuleDirectory/Custom/Kernel/Output/JavaScript/Templates/$DefaultTheme";
+        if ( $IsSubTranslation && -d $CustomJSTemplatesDir ) {
+            my @CustomJSTemplateList = $Kernel::OM->Get('Kernel::System::Main')->DirectoryRead(
+                Directory => $CustomJSTemplatesDir,
+                Filter    => '*.html.tmpl',
+                Recursive => 1,
+            );
+            push @JSTemplateList, @CustomJSTemplateList;
+        }
+
+        for my $File (@JSTemplateList) {
+
+            my $ContentRef = $Kernel::OM->Get('Kernel::System::Main')->FileRead(
+                Location => $File,
+                Mode     => 'utf8',
+            );
+
+            if ( !ref $ContentRef ) {
+                die "Can't open $File: $!";
+            }
+
+            my $Content = ${$ContentRef};
+
+            $File =~ s{^.*/(.+?)\.html\.tmpl}{$1}smx;
+
+            # Find strings marked for translation.
+            $Content =~ s{
+                \{\{
+                \s*
+                (["'])(.*?)(?<!\\)\1
+                \s*
+                \|
+                \s*
+                Translate
+            }
+            {
+                my $Word = $2 // '';
+
+                # Unescape any \" or \' signs.
+                $Word =~ s{\\"}{"}smxg;
+                $Word =~ s{\\'}{'}smxg;
+
+                if ( $Word && !$UsedWords{$Word}++ ) {
+                    push @OriginalTranslationStrings, {
+                        Location => "JS Template: $File",
+                        Source   => $Word,
+                    };
+                }
+
+                # Also save that this string was used in JS (for later use in Loader).
+                $UsedInJS{$Word} = 1;
+
+                '';
+            }egx;
+        }
+
         # add translatable strings from Perl code
         my $PerlModuleDirectory = $IsSubTranslation
             ? "$ModuleDirectory/Kernel"
@@ -292,9 +365,10 @@ sub HandleLanguage {
         }
 
         # include var/packagesetup folder for modules
-        if ($IsSubTranslation) {
+        my $PackageSetupDir = "$ModuleDirectory/var/packagesetup";
+        if ( $IsSubTranslation && -d $PackageSetupDir ) {
             my @PackageSetupModuleList = $Kernel::OM->Get('Kernel::System::Main')->DirectoryRead(
-                Directory => "$ModuleDirectory/var/packagesetup",
+                Directory => $PackageSetupDir,
                 Filter    => '*.pm',
                 Recursive => 1,
             );
@@ -351,7 +425,7 @@ sub HandleLanguage {
                 my $SkipWord;
                 $SkipWord = 1 if $Word =~ m{\$}xms;
 
-                if ($Word && !$SkipWord && !$UsedWords{$Word}++ ) {
+                if ( $Word && !$SkipWord && !$UsedWords{$Word}++ ) {
 
                     push @OriginalTranslationStrings, {
                         Location => "Perl Module: $File",
@@ -395,7 +469,7 @@ sub HandleLanguage {
             {
                 my $Word = $1 // '';
 
-                if ($Word && !$UsedWords{$Word}++) {
+                if ( $Word && !$UsedWords{$Word}++ ) {
 
                     if ($IsSubTranslation) {
                         $File =~ s{^.*/(.+\.sopm)}{$1}smx;
@@ -411,8 +485,81 @@ sub HandleLanguage {
             }egx;
         }
 
+        # add translatable strings from JavaScript code
+        my $JSDirectory = $IsSubTranslation
+            ? "$ModuleDirectory/var/httpd/htdocs/js"
+            : "$Home/var/httpd/htdocs/js";
+
+        my @JSFileList;
+        if ( -d $JSDirectory ) {
+            @JSFileList = $Kernel::OM->Get('Kernel::System::Main')->DirectoryRead(
+                Directory => $JSDirectory,
+                Filter    => '*.js',
+                Recursive => 1,
+            );
+        }
+
+        FILE:
+        for my $File (@JSFileList) {
+
+            my $ContentRef = $Kernel::OM->Get('Kernel::System::Main')->FileRead(
+                Location => $File,
+                Mode     => 'utf8',
+            );
+
+            if ( !ref $ContentRef ) {
+                die "Can't open $File: $!";
+            }
+
+            # skip js cache files
+            next FILE if ( $File =~ m{\/js\/js-cache\/}xmsg );
+
+            my $Content = ${$ContentRef};
+
+            # skip thirdparty files without custom markers
+            if ( $File =~ m{\/js\/thirdparty\/}xmsg ) {
+                next FILE if ( $Content !~ m{\/\/\s*OTRS}xmsg );
+            }
+
+            $File =~ s{^.*/(.+?)\.js}{$1}smx;
+
+            # Purge all comments
+            $Content =~ s{^ \s* // .*? \n}{\n}xmsg;
+
+            # do translation
+            $Content =~ s{
+                (?:
+                    Core.Language.Translate
+                )
+                \(
+                    \s*
+                    (["'])(.*?)(?<!\\)\1
+            }
+            {
+                my $Word = $2 // '';
+
+                # unescape any \" or \' signs
+                $Word =~ s{\\"}{"}smxg;
+                $Word =~ s{\\'}{'}smxg;
+
+                if ( $Word && !$UsedWords{$Word}++ ) {
+
+                    push @OriginalTranslationStrings, {
+                        Location => "JS File: $File",
+                        Source => $Word,
+                    };
+
+                }
+
+                # also save that this string was used in JS (for later use in Loader)
+                $UsedInJS{$Word} = 1;
+
+                '';
+            }egx;
+        }
+
         # add translatable strings from SysConfig
-        my @Strings = $Kernel::OM->Get('Kernel::System::SysConfig')->ConfigItemTranslatableStrings();
+        my @Strings = $Kernel::OM->Get('Kernel::System::SysConfig')->ConfigurationTranslatableStrings();
 
         STRING:
         for my $String ( sort @Strings ) {
@@ -538,6 +685,7 @@ sub HandleLanguage {
         LanguageFile       => $LanguageFile,
         TargetFile         => $TargetFile,
         TranslationStrings => \@TranslationStrings,
+        UsedInJS           => \%UsedInJS,
     );
 
     return 1;
@@ -634,14 +782,11 @@ sub WritePOTFile {
 
     my $Package = $Param{Module} // 'OTRS';
 
-    my $TimeObject   = $Kernel::OM->Get('Kernel::System::Time');
-    my $CreationDate = $TimeObject->SystemTime2TimeStamp(
-        SystemTime => $TimeObject->SystemTime(),
+    # build creation date, only YEAR-MO-DA HO:MI is needed without seconds
+    my $CreationDate = $Kernel::OM->Create('Kernel::System::DateTime')->Format(
+        Format => '%Y-%m-%d %H:%M+0000'
     );
 
-    # only YEAR-MO-DA HO:MI is needed without seconds
-    $CreationDate = substr( $CreationDate, 0, -3 ) . '+0000';
-
     push @POTEntries, Locale::PO->new(
         -msgid => '',
         -msgstr =>
@@ -727,6 +872,26 @@ sub WritePerlLanguageFile {
         }
     }
 
+    # add data structure for JS translations
+    my $JSData = "    \$Self->{JavaScriptStrings} = [\n";
+
+    if ( $Param{IsSubTranslation} ) {
+        $JSData = '    push @{ $Self->{JavaScriptStrings} // [] }, (' . "\n";
+    }
+
+    for my $String ( sort keys %{ $Param{UsedInJS} // {} } ) {
+        my $Key = $String;
+        $Key =~ s/'/\\'/g;
+        $JSData .= $Indent . "'" . $Key . "',\n";
+    }
+
+    if ( $Param{IsSubTranslation} ) {
+        $JSData .= "    );\n";
+    }
+    else {
+        $JSData .= "    ];\n";
+    }
+
     my %MetaData;
     my $NewOut = '';
 
@@ -738,7 +903,7 @@ sub WritePerlLanguageFile {
 
         $NewOut = <<"EOF";
 $Separator
-# Copyright (C) 2001-2018 OTRS AG, https://otrs.com/
+# Copyright (C) 2001-2019 OTRS AG, https://otrs.com/
 $Separator
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -754,6 +919,8 @@ use utf8;
 sub Data {
     my \$Self = shift;
 $Data
+
+$JSData
 }
 
 1;
@@ -794,8 +961,10 @@ EOF
     \$Self->{Completeness}        = $Completeness;
 
     # csv separator
-    \$Self->{Separator} = '$LanguageCoreObject->{Separator}';
+    \$Self->{Separator}         = '$LanguageCoreObject->{Separator}';
 
+    \$Self->{DecimalSeparator}  = '$LanguageCoreObject->{DecimalSeparator}';
+    \$Self->{ThousandSeparator} = '$LanguageCoreObject->{ThousandSeparator}';
 EOF
 
                 if ( $LanguageCoreObject->{TextDirection} ) {
@@ -808,10 +977,13 @@ EOF
                 $NewOut .= <<"EOF";
     \$Self->{Translation} = {
 $Data
+    };
+
 EOF
+                $NewOut .= $JSData . "\n";
             }
+
             if ( $_ =~ /\$\$STOP\$\$/ ) {
-                $NewOut .= "    };\n";
                 $NewOut .= $Line;
                 $MetaData{DataPrinted} = 0;
             }
