@@ -1,9 +1,9 @@
 # --
-# Copyright (C) 2001-2018 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2019 OTRS AG, https://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (AGPL). If you
-# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
+# the enclosed file COPYING for license information (GPL). If you
+# did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
 # --
 
 package Kernel::System::EmailParser;
@@ -746,7 +746,7 @@ sub PartsAttachments {
     elsif ( $PartData{ContentType} eq 'message/rfc822' ) {
 
         my ($SubjectString) = $Part->as_string() =~ m/^Subject: ([^\n]*(\n[ \t][^\n]*)*)/m;
-        my $Subject = $Self->_DecodeString( String => $SubjectString );
+        my $Subject = $Self->_DecodeString( String => $SubjectString ) . '.eml';
 
         # cleanup filename
         $Subject = $Kernel::OM->Get('Kernel::System::Main')->FilenameCleanUp(
@@ -756,9 +756,9 @@ sub PartsAttachments {
 
         if ( $Subject eq '' ) {
             $Self->{NoFilenamePartCounter}++;
-            $Subject = "Unbenannt-$Self->{NoFilenamePartCounter}";
+            $Subject = "Untitled-$Self->{NoFilenamePartCounter}" . '.eml';
         }
-        $PartData{Filename} = $Subject . '.eml';
+        $PartData{Filename} = $Subject;
     }
     else {
         $Self->{NoFilenamePartCounter}++;
@@ -808,7 +808,7 @@ sub PartsAttachments {
         )
     {
         # Is it a plain or HTML body?
-        my $MimeType = $PartData{ContentType} =~ /text\/html/i ? 'text/html' : 'text/plain';
+        my $MimeType       = $PartData{ContentType} =~ /text\/html/i ? 'text/html' : 'text/plain';
         my $TargetMimeType = $MimeType;
 
         my $BodyAttachmentKey = "MultipartMixedBodyAttachment$MimeType";
@@ -1107,11 +1107,11 @@ sub _MailAddressParse {
 
 =head1 TERMS AND CONDITIONS
 
-This software is part of the OTRS project (L<http://otrs.org/>).
+This software is part of the OTRS project (L<https://otrs.org/>).
 
 This software comes with ABSOLUTELY NO WARRANTY. For details, see
-the enclosed file COPYING for license information (AGPL). If you
-did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
+the enclosed file COPYING for license information (GPL). If you
+did not receive this file, see L<https://www.gnu.org/licenses/gpl-3.0.txt>.
 
 =cut
 
