@@ -19,15 +19,12 @@ our $ObjectManagerDisabled = 1;
 
 Kernel::System::Ticket::TicketACL - ticket ACL lib
 
-=head1 SYNOPSIS
+=head1 DESCRIPTION
 
 All ticket ACL functions.
 
-=over 4
 
-=cut
-
-=item TicketAcl()
+=head2 TicketAcl()
 
 Restricts the Data parameter sent to a subset of it, depending on a group of user defied rules
 called ACLs. The reduced subset can be access from TicketACLData() if ReturnType parameter is set
@@ -58,6 +55,8 @@ Example to restrict ticket actions:
 
         QueueID          => 123,                      # Optional
         Queue            => 'some queue name',        # Optional
+        NewQueueID       => 123,                      # Optional, QueueID or NewQueueID can be
+                                                      #   used and they both refers to QueueID
 
         ServiceID        => 123,                      # Optional
         Service          => 'some service name',      # Optional
@@ -920,7 +919,7 @@ sub TicketAcl {
     return 1;
 }
 
-=item TicketAclData()
+=head2 TicketAclData()
 
 return the current ACL data hash after TicketAcl()
 
@@ -934,7 +933,7 @@ sub TicketAclData {
     return %{ $Self->{TicketAclData} || {} };
 }
 
-=item TicketAclActionData()
+=head2 TicketAclActionData()
 
 return the current ACL action data hash after TicketAcl()
 
@@ -955,7 +954,7 @@ sub TicketAclActionData {
 
 =cut
 
-=item _GetChecks()
+=head2 _GetChecks()
 
 creates two check hashes (one for current data updatable via AJAX refreshes and another for
 static ticket data stored in the DB) with the required data to use as a basis to match the ACLs
@@ -1133,6 +1132,19 @@ sub _GetChecks {
         }
     }
 
+    # Check for ActivityEntityID if set as parameter (ProcessManagement).
+    if ( ( $CheckAll || $RequiredChecks{Process} ) && $Param{ActivityEntityID} ) {
+
+        my $Activity = $Kernel::OM->Get('Kernel::System::ProcessManagement::Activity')->ActivityGet(
+            ActivityEntityID => $Param{ActivityEntityID},
+            Interface        => [$Interface],
+        );
+
+        if ( IsHashRefWithData($Activity) ) {
+            $Checks{Process}->{ActivityEntityID} = $Param{ActivityEntityID};
+        }
+    }
+
     # check for dynamic fields
     if ( IsHashRefWithData( $Param{DynamicField} ) ) {
         $Checks{DynamicField} = $Param{DynamicField};
@@ -1327,6 +1339,10 @@ sub _GetChecks {
         # get queue object
         my $QueueObject = $Kernel::OM->Get('Kernel::System::Queue');
 
+        if ( $Param{NewQueueID} && !$Param{QueueID} ) {
+            $Param{QueueID} = $Param{NewQueueID};
+        }
+
         if ( $Param{QueueID} ) {
             my %Queue = $QueueObject->QueueGet( ID => $Param{QueueID} );
             $Checks{Queue} = \%Queue;
@@ -2045,7 +2061,7 @@ sub _GetChecks {
     };
 }
 
-=item _CompareMatchWithData()
+=head2 _CompareMatchWithData()
 
 Compares a properties element with the data sent to the ACL, the compare results varies on how the
 ACL properties where defined including normal, negated, regular expression and negated regular
@@ -2191,8 +2207,6 @@ sub _CompareMatchWithData {
 
 =end Internal:
 
-=back
-
 =head1 TERMS AND CONDITIONS
 
 This software is part of the OTRS project (L<https://otrs.org/>).
